@@ -134,7 +134,9 @@ pub fn get_asset_pairs(assets_dir: &str) -> Result<HashMap<usize, AssetPair>> {
             .to_string();
 
         let m = File::open(&metadata_file)?;
-        let metadata: Metadata = serde_json::from_reader(m)?;
+        let metadata: Metadata = serde_json::from_reader(m).map_err(|e| {
+            anyhow!("Failed to read metadata file '{metadata_file}' with error: {e}")
+        })?;
         let name = metadata.name.clone();
 
         let asset_pair = AssetPair {
@@ -170,12 +172,22 @@ fn encode(file: &str) -> Result<String> {
 
 pub fn get_updated_metadata(metadata_file: &str, media_link: &str) -> Result<String> {
     let mut metadata: Metadata = {
-        let m = OpenOptions::new().read(true).open(metadata_file)?;
+        let m = OpenOptions::new()
+            .read(true)
+            .open(metadata_file)
+            .map_err(|e| {
+                anyhow!("Failed to read metadata file '{metadata_file}' with error: {e}")
+            })?;
         serde_json::from_reader(&m)?
     };
 
+    for file in &mut metadata.properties.files {
+        if file.uri.eq(&metadata.image) {
+            file.uri = media_link.to_string();
+        }
+    }
+
     metadata.image = media_link.to_string();
-    metadata.properties.files[0].uri = media_link.to_string();
 
     Ok(serde_json::to_string(&metadata).unwrap())
 }
